160,206 Commits over 4,566 Days - 1.46cph!

12 Days Ago
Merge from main
12 Days Ago
Merge from render_pipeline_testing
12 Days Ago
merge from buildingprivilege_cache
12 Days Ago
Comment
12 Days Ago
Fixed regression with player boat privs when using the cache
12 Days Ago
merge from gate_speed_fix
12 Days Ago
Cleaned up building priv cache vs vis tests
12 Days Ago
Merge from main
12 Days Ago
update from main
Rin
12 Days Ago
▄▅▆▄▍▅▉▄▆█ ▊▋█▉▌█ ▄▇▇▇█▉ █▄▌▊ ▉▉▄ ▉▍▅▊ ▍▆▉▋▊▍▆ ▇▆▉▉▋▌▍▍▉▆▉▌▌▆▅▉▊▆▅▇▊▍▍▋█▉▄▉▆▇▋▇▇▄▄▅▍▌▆▄▊▉▄▌▄▅▆█▋▋▌▉▉▊▊█▇▋▄▅▌█▊▆█▅█▌▆▄▉▌▍▄▊▄▍▅▋▇▇▊▋▉▉
12 Days Ago
Merge from neon_sfx_occluded
12 Days Ago
Neon sign sounds are now occluded Had to adjust their volume slightly
12 Days Ago
▊▇▇▄▌▍▍▆ ▌▊▆▊ ▉▉▌ █▆▄▊▇ █▄▅▉ ▍▇▋ █▆ ▅▄▉▅▉ ▌▄█▋▇ ▄▉▆▉▄▉ ▉▄ ▆▊▇█ ▌▅▄ ▉▉▅▋▅█▅ ▉▍▊▉▊▉▍▊▋▄▉▋ ▉▌▆▉▅ ▄█▆ ▉▋▍▋▆▇ ▄▄▆ ▌▊▊▌▌▍ ▆▌ █▌▍▅▉▍▇ ▌▄▉▅▇ ▄▍▊ ▋▆▊ ▌▄ ▍▇▆█▌█ ▍▇ ▍ ▍▊▌ ▍▊▋▅█▄▍▌▉▍▅ ▋▌ ▋ ▅▌▄▍▉▆ ▄▆▍▅▉█ ▆▅ ▍▄▍ ▅ ▍▆▇▇▆ ▉▆▅ ▊▄ █▄▅ █▉▅▆▄▇▄
12 Days Ago
Merge from solar_explosive_fix
12 Days Ago
Fixed attached explosives getting scaled incorrectly on the solar panel
12 Days Ago
Merge from spray_reskin_atlas_fix
12 Days Ago
Fixed incorrect material replacement when using the spraycan to reskin the double door at low quality
12 Days Ago
Fixed chainlink gate speed opening 2x slower
13 Days Ago
Merge from mount_size_changes
13 Days Ago
Cleanup
13 Days Ago
NPC mount points can now specify a size and overlaps - so a large mount point could overlap other mount points and make them inaccessible Added a new, single large mount point to the 2 module flatbed that overlaps the two existing small mount points Prevents being able to mount two cows to large flatbed, still allows two sheep to be loaded
13 Days Ago
Merge from OreNodeNetworkFix
13 Days Ago
Merge from WeaponRackFlamethrower
13 Days Ago
▋▅█▇▅▇ ▋▍▋▋ █▅▅▌▌▆▊█▅▄▅▅▆▅▆▋▄▌▇█
13 Days Ago
▊▌▍▍▌ ▉▉█▊█▄▊ ▍▌▇▊ ▅▍█ ▇▌ ▄▍█▋▊▉▇█▇▌▋▋▊ ▊▆▄▅ ▋ ▄▉▅▌█▌▄ ▇▌ ▉▌█▍▉██ ▊▌▉▆ ▆▍ ▅▍▇▊ ▇▌▆ ▅▄ ▊ ▄▅▇▌ ▊▅▉▊ ▋▆▋ ▌▉ ▍▌▆▇▆▄ ██▌▉▄▇ ▅▉ ▌▉▅▄▊▉▆▇▋▅▊▋█▇ ▍ ▉▍▆▇██▋▅▉▄▅▉▅▅▊▇█▉ ▊▊▅▉▅▄ ▆▇▉▅▄▊ █▊▄ ▉▇▊▋▍▋▅▄█ ▉▄▉▍▅▆ ▅▌ ▅▆▋▊▌▍▋ ▆▄▄▌▊▄▌ ▊▉▉▉▋▄▉ █▌▉▊▊ ▍▅▉▇ ▅▇ ▍▆▉ ▅▌ █▋█▌
13 Days Ago
Fixed error spam on ultra-wide screens with the nailgun, paintball gun and bowless crossbow viewmodels. Small rounding errors in the viewmodel sway/bob were snowballing each frame until Unity rejected the rotation. No visual change, just trying for a clean console.
13 Days Ago
Merge from terrain_config_load
13 Days Ago
Possibly fixed terrain configs not loading in a demo
13 Days Ago
Merge from main
13 Days Ago
▌▌▊█▌▌ ▌▇▉▆ ▊▊▉▆▍█▊▅▆▊▍▍▅▋▋▌▄▉
13 Days Ago
▉▆▆▍ █▇█▆▄▌▋▆▇▍ ▉▍▊ ▊▌▍▇▍▅▊ ▉▅▋▅ █▊▅▍ ▍▇▌ ▆▅▄▊▊▇▄▄▌ ▆▆▇ ▇ ▇██▊▅▇▊▉▅▊▇▆▊ ▇ ▌█▊▌ ▆▄ ▄▆▋▉▄ ▆▉▇▍ ▆▇▆▋ ▇▋ ▄▅▉▋▊▊
13 Days Ago
merge from buildingprivilege_cache
13 Days Ago
Cleanup
13 Days Ago
▌▅▌▅▉▇ ▋▋▆▉ ▆▇▉▇
13 Days Ago
Reordered the check so bases with no TC are cheaper
13 Days Ago
Convared the vehicle and entity privilege changes under buildingmanager.privilegecache
13 Days Ago
Building privilege tests
13 Days Ago
Legacy shelters, vehicles and boat building stations no longer use Vis queries Same base same spot: GetVehicleBuildingPrivilege 0.34ms -> 0.01ms GetEntityBuildingPrivilege 0.84ms -> ~0
13 Days Ago
nailgun skinnable initial setup
13 Days Ago
Optimize server startup time by 72s (230s -> 158s) by fetching the spawnables only once instead of doing it for each of the 100 spawn populations
13 Days Ago
merge from main
13 Days Ago
Optimize server startup time by 24s (254s -> 230s) by using HashSet to check for duplicate player models
13 Days Ago
Added coconuts to small_a, small_b, small_c and med_a
13 Days Ago
Sort the cells oldest first
13 Days Ago
Store each blocks bound centre and net id in the grid so: - blocks out of the query radius are skipped without a dictionary lookup - the age check doesnt read every block from memory Only run HasColliderWithinSphere when the block bounds aren't entirely inside the search sphere Around 0.09ms for GetBuildingPrivilege in that same base, same spot
13 Days Ago
LightGroupAtTime optimization pass
13 Days Ago
Merge from livestock_animals, fix regression and red test
13 Days Ago
Fix regression caught by Led_TwoInSingleFile_StandSideBySide test
13 Days Ago
- Skip the bounds check for blocks that aren't older than the current best block - Visit the cell you're standing in first Skips a lot of work when standing in the core or middle of a base